# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.datacatalog.v1",
    manifest={
        "DataSource",
        "StorageProperties",
    },
)


class DataSource(proto.Message):
    r"""Physical location of an entry.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        service (google.cloud.datacatalog_v1.types.DataSource.Service):
            Service that physically stores the data.
        resource (str):
            Full name of a resource as defined by the service. For
            example:

            ``//bigquery.googleapis.com/projects/{PROJECT_ID}/locations/{LOCATION}/datasets/{DATASET_ID}/tables/{TABLE_ID}``
        source_entry (str):
            Output only. Data Catalog entry name, if
            applicable.
        storage_properties (google.cloud.datacatalog_v1.types.StorageProperties):
            Detailed properties of the underlying
            storage.

            This field is a member of `oneof`_ ``properties``.
    """

    class Service(proto.Enum):
        r"""Name of a service that stores the data.

        Values:
            SERVICE_UNSPECIFIED (0):
                Default unknown service.
            CLOUD_STORAGE (1):
                Google Cloud Storage service.
            BIGQUERY (2):
                BigQuery service.
        """
        SERVICE_UNSPECIFIED = 0
        CLOUD_STORAGE = 1
        BIGQUERY = 2

    service: Service = proto.Field(
        proto.ENUM,
        number=1,
        enum=Service,
    )
    resource: str = proto.Field(
        proto.STRING,
        number=2,
    )
    source_entry: str = proto.Field(
        proto.STRING,
        number=3,
    )
    storage_properties: "StorageProperties" = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="properties",
        message="StorageProperties",
    )


class StorageProperties(proto.Message):
    r"""Details the properties of the underlying storage.

    Attributes:
        file_pattern (MutableSequence[str]):
            Patterns to identify a set of files for this fileset.

            Examples of a valid ``file_pattern``:

            -  ``gs://bucket_name/dir/*``: matches all files in the
               ``bucket_name/dir`` directory
            -  ``gs://bucket_name/dir/**``: matches all files in the
               ``bucket_name/dir`` and all subdirectories recursively
            -  ``gs://bucket_name/file*``: matches files prefixed by
               ``file`` in ``bucket_name``
            -  ``gs://bucket_name/??.txt``: matches files with two
               characters followed by ``.txt`` in ``bucket_name``
            -  ``gs://bucket_name/[aeiou].txt``: matches files that
               contain a single vowel character followed by ``.txt`` in
               ``bucket_name``
            -  ``gs://bucket_name/[a-m].txt``: matches files that
               contain ``a``, ``b``, ... or ``m`` followed by ``.txt``
               in ``bucket_name``
            -  ``gs://bucket_name/a/*/b``: matches all files in
               ``bucket_name`` that match the ``a/*/b`` pattern, such as
               ``a/c/b``, ``a/d/b``
            -  ``gs://another_bucket/a.txt``: matches
               ``gs://another_bucket/a.txt``
        file_type (str):
            File type in MIME format, for example, ``text/plain``.
    """

    file_pattern: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=1,
    )
    file_type: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.datacatalog_v1.types import common, timestamps

__protobuf__ = proto.module(
    package="google.cloud.datacatalog.v1",
    manifest={
        "Taxonomy",
        "PolicyTag",
        "CreateTaxonomyRequest",
        "DeleteTaxonomyRequest",
        "UpdateTaxonomyRequest",
        "ListTaxonomiesRequest",
        "ListTaxonomiesResponse",
        "GetTaxonomyRequest",
        "CreatePolicyTagRequest",
        "DeletePolicyTagRequest",
        "UpdatePolicyTagRequest",
        "ListPolicyTagsRequest",
        "ListPolicyTagsResponse",
        "GetPolicyTagRequest",
    },
)


class Taxonomy(proto.Message):
    r"""A taxonomy is a collection of hierarchical policy tags that classify
    data along a common axis.

    For example, a "data sensitivity" taxonomy might contain the
    following policy tags:

    ::

       + PII
         + Account number
         + Age
         + SSN
         + Zipcode
       + Financials
         + Revenue

    A "data origin" taxonomy might contain the following policy tags:

    ::

       + User data
       + Employee data
       + Partner data
       + Public data

    Attributes:
        name (str):
            Output only. Resource name of this taxonomy
            in URL format.
            Note: Policy tag manager generates unique
            taxonomy IDs.
        display_name (str):
            Required. User-defined name of this taxonomy.
            The name can't start or end with spaces, must
            contain only Unicode letters, numbers,
            underscores, dashes, and spaces, and be at most
            200 bytes long when encoded in UTF-8.

            The taxonomy display name must be unique within
            an organization.
        description (str):
            Optional. Description of this taxonomy. If
            not set, defaults to empty.
            The description must contain only Unicode
            characters, tabs, newlines, carriage returns,
            and page breaks, and be at most 2000 bytes long
            when encoded in UTF-8.
        policy_tag_count (int):
            Output only. Number of policy tags in this
            taxonomy.
        taxonomy_timestamps (google.cloud.datacatalog_v1.types.SystemTimestamps):
            Output only. Creation and modification
            timestamps of this taxonomy.
        activated_policy_types (MutableSequence[google.cloud.datacatalog_v1.types.Taxonomy.PolicyType]):
            Optional. A list of policy types that are
            activated for this taxonomy. If not set,
            defaults to an empty list.
        service (google.cloud.datacatalog_v1.types.Taxonomy.Service):
            Output only. Identity of the service which
            owns the Taxonomy. This field is only populated
            when the taxonomy is created by a Google Cloud
            service. Currently only 'DATAPLEX' is supported.
    """

    class PolicyType(proto.Enum):
        r"""Defines policy types where the policy tags can be used for.

        Values:
            POLICY_TYPE_UNSPECIFIED (0):
                Unspecified policy type.
            FINE_GRAINED_ACCESS_CONTROL (1):
                Fine-grained access control policy that
                enables access control on tagged sub-resources.
        """
        POLICY_TYPE_UNSPECIFIED = 0
        FINE_GRAINED_ACCESS_CONTROL = 1

    class Service(proto.Message):
        r"""The source system of the Taxonomy.

        Attributes:
            name (google.cloud.datacatalog_v1.types.ManagingSystem):
                The Google Cloud service name.
            identity (str):
                The service agent for the service.
        """

        name: common.ManagingSystem = proto.Field(
            proto.ENUM,
            number=1,
            enum=common.ManagingSystem,
        )
        identity: str = proto.Field(
            proto.STRING,
            number=2,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    description: str = proto.Field(
        proto.STRING,
        number=3,
    )
    policy_tag_count: int = proto.Field(
        proto.INT32,
        number=4,
    )
    taxonomy_timestamps: timestamps.SystemTimestamps = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamps.SystemTimestamps,
    )
    activated_policy_types: MutableSequence[PolicyType] = proto.RepeatedField(
        proto.ENUM,
        number=6,
        enum=PolicyType,
    )
    service: Service = proto.Field(
        proto.MESSAGE,
        number=7,
        message=Service,
    )


class PolicyTag(proto.Message):
    r"""Denotes one policy tag in a taxonomy, for example, SSN.

    Policy tags can be defined in a hierarchy. For example:

    ::

       + Geolocation
         + LatLong
         + City
         + ZipCode

    Where the "Geolocation" policy tag contains three children.

    Attributes:
        name (str):
            Output only. Resource name of this policy tag
            in the URL format.
            The policy tag manager generates unique taxonomy
            IDs and policy tag IDs.
        display_name (str):
            Required. User-defined name of this policy
            tag.
            The name can't start or end with spaces and must
            be unique within the parent taxonomy, contain
            only Unicode letters, numbers, underscores,
            dashes and spaces, and be at most 200 bytes long
            when encoded in UTF-8.
        description (str):
            Description of this policy tag. If not set,
            defaults to empty.
            The description must contain only Unicode
            characters, tabs, newlines, carriage returns and
            page breaks, and be at most 2000 bytes long when
            encoded in UTF-8.
        parent_policy_tag (str):
            Resource name of this policy tag's parent
            policy tag. If empty, this is a top level tag.
            If not set, defaults to an empty string.
            For example, for the "LatLong" policy tag in the
            example above, this field contains the resource
            name of the "Geolocation" policy tag, and, for
            "Geolocation", this field is empty.
        child_policy_tags (MutableSequence[str]):
            Output only. Resource names of child policy
            tags of this policy tag.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    description: str = proto.Field(
        proto.STRING,
        number=3,
    )
    parent_policy_tag: str = proto.Field(
        proto.STRING,
        number=4,
    )
    child_policy_tags: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )


class CreateTaxonomyRequest(proto.Message):
    r"""Request message for
    [CreateTaxonomy][google.cloud.datacatalog.v1.PolicyTagManager.CreateTaxonomy].

    Attributes:
        parent (str):
            Required. Resource name of the project that
            the taxonomy will belong to.
        taxonomy (google.cloud.datacatalog_v1.types.Taxonomy):
            The taxonomy to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    taxonomy: "Taxonomy" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="Taxonomy",
    )


class DeleteTaxonomyRequest(proto.Message):
    r"""Request message for
    [DeleteTaxonomy][google.cloud.datacatalog.v1.PolicyTagManager.DeleteTaxonomy].

    Attributes:
        name (str):
            Required. Resource name of the taxonomy to
            delete.
            Note: All policy tags in this taxonomy are also
            deleted.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateTaxonomyRequest(proto.Message):
    r"""Request message for
    [UpdateTaxonomy][google.cloud.datacatalog.v1.PolicyTagManager.UpdateTaxonomy].

    Attributes:
        taxonomy (google.cloud.datacatalog_v1.types.Taxonomy):
            The taxonomy to update. You can update only
            its description, display name, and activated
            policy types.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Specifies fields to update. If not set, defaults to all
            fields you can update.

            For more information, see [FieldMask]
            (https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask).
    """

    taxonomy: "Taxonomy" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="Taxonomy",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class ListTaxonomiesRequest(proto.Message):
    r"""Request message for
    [ListTaxonomies][google.cloud.datacatalog.v1.PolicyTagManager.ListTaxonomies].

    Attributes:
        parent (str):
            Required. Resource name of the project to
            list the taxonomies of.
        page_size (int):
            The maximum number of items to return. Must
            be a value between 1 and 1000 inclusively. If
            not set, defaults to 50.
        page_token (str):
            The pagination token of the next results
            page. If not set, the first page is returned.
            The token is returned in the response to a
            previous list request.
        filter (str):
            Supported field for filter is 'service' and
            value is 'dataplex'. Eg: service=dataplex.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListTaxonomiesResponse(proto.Message):
    r"""Response message for
    [ListTaxonomies][google.cloud.datacatalog.v1.PolicyTagManager.ListTaxonomies].

    Attributes:
        taxonomies (MutableSequence[google.cloud.datacatalog_v1.types.Taxonomy]):
            Taxonomies that the project contains.
        next_page_token (str):
            Pagination token of the next results page.
            Empty if there are no more results in the list.
    """

    @property
    def raw_page(self):
        return self

    taxonomies: MutableSequence["Taxonomy"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Taxonomy",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetTaxonomyRequest(proto.Message):
    r"""Request message for
    [GetTaxonomy][google.cloud.datacatalog.v1.PolicyTagManager.GetTaxonomy].

    Attributes:
        name (str):
            Required. Resource name of the taxonomy to
            get.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CreatePolicyTagRequest(proto.Message):
    r"""Request message for
    [CreatePolicyTag][google.cloud.datacatalog.v1.PolicyTagManager.CreatePolicyTag].

    Attributes:
        parent (str):
            Required. Resource name of the taxonomy that
            the policy tag will belong to.
        policy_tag (google.cloud.datacatalog_v1.types.PolicyTag):
            The policy tag to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    policy_tag: "PolicyTag" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="PolicyTag",
    )


class DeletePolicyTagRequest(proto.Message):
    r"""Request message for
    [DeletePolicyTag][google.cloud.datacatalog.v1.PolicyTagManager.DeletePolicyTag].

    Attributes:
        name (str):
            Required. Resource name of the policy tag to
            delete.
            Note: All of its descendant policy tags are also
            deleted.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdatePolicyTagRequest(proto.Message):
    r"""Request message for
    [UpdatePolicyTag][google.cloud.datacatalog.v1.PolicyTagManager.UpdatePolicyTag].

    Attributes:
        policy_tag (google.cloud.datacatalog_v1.types.PolicyTag):
            The policy tag to update. You can update only
            its description, display name, and parent policy
            tag fields.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Specifies the fields to update.

            You can update only display name, description, and parent
            policy tag. If not set, defaults to all updatable fields.
            For more information, see [FieldMask]
            (https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask).
    """

    policy_tag: "PolicyTag" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="PolicyTag",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class ListPolicyTagsRequest(proto.Message):
    r"""Request message for
    [ListPolicyTags][google.cloud.datacatalog.v1.PolicyTagManager.ListPolicyTags].

    Attributes:
        parent (str):
            Required. Resource name of the taxonomy to
            list the policy tags of.
        page_size (int):
            The maximum number of items to return. Must
            be a value between 1 and 1000 inclusively.
            If not set, defaults to 50.
        page_token (str):
            The pagination token of the next results
            page. If not set, returns the first page.

            The token is returned in the response to a
            previous list request.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListPolicyTagsResponse(proto.Message):
    r"""Response message for
    [ListPolicyTags][google.cloud.datacatalog.v1.PolicyTagManager.ListPolicyTags].

    Attributes:
        policy_tags (MutableSequence[google.cloud.datacatalog_v1.types.PolicyTag]):
            The policy tags that belong to the taxonomy.
        next_page_token (str):
            Pagination token of the next results page.
            Empty if there are no more results in the list.
    """

    @property
    def raw_page(self):
        return self

    policy_tags: MutableSequence["PolicyTag"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="PolicyTag",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetPolicyTagRequest(proto.Message):
    r"""Request message for
    [GetPolicyTag][google.cloud.datacatalog.v1.PolicyTagManager.GetPolicyTag].

    Attributes:
        name (str):
            Required. Resource name of the policy tag.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.datacatalog.v1",
    manifest={
        "Schema",
        "ColumnSchema",
    },
)


class Schema(proto.Message):
    r"""Represents a schema, for example, a BigQuery, GoogleSQL, or
    Avro schema.

    Attributes:
        columns (MutableSequence[google.cloud.datacatalog_v1.types.ColumnSchema]):
            The unified GoogleSQL-like schema of columns.
            The overall maximum number of columns and nested
            columns is 10,000. The maximum nested depth is
            15 levels.
    """

    columns: MutableSequence["ColumnSchema"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="ColumnSchema",
    )


class ColumnSchema(proto.Message):
    r"""A column within a schema. Columns can be nested inside
    other columns.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        column (str):
            Required. Name of the column.
            Must be a UTF-8 string without dots (.).
            The maximum size is 64 bytes.
        type_ (str):
            Required. Type of the column.
            Must be a UTF-8 string with the maximum size of
            128 bytes.
        description (str):
            Optional. Description of the column. Default
            value is an empty string.
            The description must be a UTF-8 string with the
            maximum size of 2000 bytes.
        mode (str):
            Optional. A column's mode indicates whether values in this
            column are required, nullable, or repeated.

            Only ``NULLABLE``, ``REQUIRED``, and ``REPEATED`` values are
            supported. Default mode is ``NULLABLE``.
        default_value (str):
            Optional. Default value for the column.
        ordinal_position (int):
            Optional. Ordinal position
        highest_indexing_type (google.cloud.datacatalog_v1.types.ColumnSchema.IndexingType):
            Optional. Most important inclusion of this
            column.
        subcolumns (MutableSequence[google.cloud.datacatalog_v1.types.ColumnSchema]):
            Optional. Schema of sub-columns. A column can
            have zero or more sub-columns.
        looker_column_spec (google.cloud.datacatalog_v1.types.ColumnSchema.LookerColumnSpec):
            Looker specific column info of this column.

            This field is a member of `oneof`_ ``system_spec``.
        gc_rule (str):
            Optional. Garbage collection policy for the
            column or column family. Applies to systems like
            Cloud Bigtable.
    """

    class IndexingType(proto.Enum):
        r"""Specifies inclusion of the column in an index

        Values:
            INDEXING_TYPE_UNSPECIFIED (0):
                Unspecified.
            INDEXING_TYPE_NONE (1):
                Column not a part of an index.
            INDEXING_TYPE_NON_UNIQUE (2):
                Column Part of non unique index.
            INDEXING_TYPE_UNIQUE (3):
                Column part of unique index.
            INDEXING_TYPE_PRIMARY_KEY (4):
                Column part of the primary key.
        """
        INDEXING_TYPE_UNSPECIFIED = 0
        INDEXING_TYPE_NONE = 1
        INDEXING_TYPE_NON_UNIQUE = 2
        INDEXING_TYPE_UNIQUE = 3
        INDEXING_TYPE_PRIMARY_KEY = 4

    class LookerColumnSpec(proto.Message):
        r"""Column info specific to Looker System.

        Attributes:
            type_ (google.cloud.datacatalog_v1.types.ColumnSchema.LookerColumnSpec.LookerColumnType):
                Looker specific column type of this column.
        """

        class LookerColumnType(proto.Enum):
            r"""Column type in Looker.

            Values:
                LOOKER_COLUMN_TYPE_UNSPECIFIED (0):
                    Unspecified.
                DIMENSION (1):
                    Dimension.
                DIMENSION_GROUP (2):
                    Dimension group - parent for Dimension.
                FILTER (3):
                    Filter.
                MEASURE (4):
                    Measure.
                PARAMETER (5):
                    Parameter.
            """
            LOOKER_COLUMN_TYPE_UNSPECIFIED = 0
            DIMENSION = 1
            DIMENSION_GROUP = 2
            FILTER = 3
            MEASURE = 4
            PARAMETER = 5

        type_: "ColumnSchema.LookerColumnSpec.LookerColumnType" = proto.Field(
            proto.ENUM,
            number=1,
            enum="ColumnSchema.LookerColumnSpec.LookerColumnType",
        )

    column: str = proto.Field(
        proto.STRING,
        number=6,
    )
    type_: str = proto.Field(
        proto.STRING,
        number=1,
    )
    description: str = proto.Field(
        proto.STRING,
        number=2,
    )
    mode: str = proto.Field(
        proto.STRING,
        number=3,
    )
    default_value: str = proto.Field(
        proto.STRING,
        number=8,
    )
    ordinal_position: int = proto.Field(
        proto.INT32,
        number=9,
    )
    highest_indexing_type: IndexingType = proto.Field(
        proto.ENUM,
        number=10,
        enum=IndexingType,
    )
    subcolumns: MutableSequence["ColumnSchema"] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message="ColumnSchema",
    )
    looker_column_spec: LookerColumnSpec = proto.Field(
        proto.MESSAGE,
        number=18,
        oneof="system_spec",
        message=LookerColumnSpec,
    )
    gc_rule: str = proto.Field(
        proto.STRING,
        number=11,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.cloud.datacatalog_v1beta1.types import policytagmanager

__protobuf__ = proto.module(
    package="google.cloud.datacatalog.v1beta1",
    manifest={
        "SerializedTaxonomy",
        "SerializedPolicyTag",
        "ImportTaxonomiesRequest",
        "InlineSource",
        "ImportTaxonomiesResponse",
        "ExportTaxonomiesRequest",
        "ExportTaxonomiesResponse",
    },
)


class SerializedTaxonomy(proto.Message):
    r"""Message capturing a taxonomy and its policy tag hierarchy as
    a nested proto. Used for taxonomy import/export and mutation.

    Attributes:
        display_name (str):
            Required. Display name of the taxonomy. Max
            200 bytes when encoded in UTF-8.
        description (str):
            Description of the serialized taxonomy. The
            length of the description is limited to 2000
            bytes when encoded in UTF-8. If not set,
            defaults to an empty description.
        policy_tags (MutableSequence[google.cloud.datacatalog_v1beta1.types.SerializedPolicyTag]):
            Top level policy tags associated with the
            taxonomy if any.
    """

    display_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    description: str = proto.Field(
        proto.STRING,
        number=2,
    )
    policy_tags: MutableSequence["SerializedPolicyTag"] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="SerializedPolicyTag",
    )


class SerializedPolicyTag(proto.Message):
    r"""Message representing one policy tag when exported as a nested
    proto.

    Attributes:
        display_name (str):
            Required. Display name of the policy tag. Max
            200 bytes when encoded in UTF-8.
        description (str):
            Description of the serialized policy tag. The
            length of the description is limited to 2000
            bytes when encoded in UTF-8. If not set,
            defaults to an empty description.
        child_policy_tags (MutableSequence[google.cloud.datacatalog_v1beta1.types.SerializedPolicyTag]):
            Children of the policy tag if any.
    """

    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    description: str = proto.Field(
        proto.STRING,
        number=3,
    )
    child_policy_tags: MutableSequence["SerializedPolicyTag"] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message="SerializedPolicyTag",
    )


class ImportTaxonomiesRequest(proto.Message):
    r"""Request message for
    [ImportTaxonomies][google.cloud.datacatalog.v1beta1.PolicyTagManagerSerialization.ImportTaxonomies].


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        parent (str):
            Required. Resource name of project that the
            newly created taxonomies will belong to.
        inline_source (google.cloud.datacatalog_v1beta1.types.InlineSource):
            Inline source used for taxonomies import

            This field is a member of `oneof`_ ``source``.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    inline_source: "InlineSource" = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="source",
        message="InlineSource",
    )


class InlineSource(proto.Message):
    r"""Inline source used for taxonomies import.

    Attributes:
        taxonomies (MutableSequence[google.cloud.datacatalog_v1beta1.types.SerializedTaxonomy]):
            Required. Taxonomies to be imported.
    """

    taxonomies: MutableSequence["SerializedTaxonomy"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="SerializedTaxonomy",
    )


class ImportTaxonomiesResponse(proto.Message):
    r"""Response message for
    [ImportTaxonomies][google.cloud.datacatalog.v1beta1.PolicyTagManagerSerialization.ImportTaxonomies].

    Attributes:
        taxonomies (MutableSequence[google.cloud.datacatalog_v1beta1.types.Taxonomy]):
            Taxonomies that were imported.
    """

    taxonomies: MutableSequence[policytagmanager.Taxonomy] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=policytagmanager.Taxonomy,
    )


class ExportTaxonomiesRequest(proto.Message):
    r"""Request message for
    [ExportTaxonomies][google.cloud.datacatalog.v1beta1.PolicyTagManagerSerialization.ExportTaxonomies].


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        parent (str):
            Required. Resource name of the project that
            taxonomies to be exported will share.
        taxonomies (MutableSequence[str]):
            Required. Resource names of the taxonomies to
            be exported.
        serialized_taxonomies (bool):
            Export taxonomies as serialized taxonomies.

            This field is a member of `oneof`_ ``destination``.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    taxonomies: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )
    serialized_taxonomies: bool = proto.Field(
        proto.BOOL,
        number=3,
        oneof="destination",
    )


class ExportTaxonomiesResponse(proto.Message):
    r"""Response message for
    [ExportTaxonomies][google.cloud.datacatalog.v1beta1.PolicyTagManagerSerialization.ExportTaxonomies].

    Attributes:
        taxonomies (MutableSequence[google.cloud.datacatalog_v1beta1.types.SerializedTaxonomy]):
            List of taxonomies and policy tags in a tree
            structure.
    """

    taxonomies: MutableSequence["SerializedTaxonomy"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="SerializedTaxonomy",
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.datacatalog.v1beta1",
    manifest={
        "Schema",
        "ColumnSchema",
    },
)


class Schema(proto.Message):
    r"""Represents a schema (e.g. BigQuery, GoogleSQL, Avro schema).

    Attributes:
        columns (MutableSequence[google.cloud.datacatalog_v1beta1.types.ColumnSchema]):
            Required. Schema of columns. A maximum of
            10,000 columns and sub-columns can be specified.
    """

    columns: MutableSequence["ColumnSchema"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="ColumnSchema",
    )


class ColumnSchema(proto.Message):
    r"""Representation of a column within a schema. Columns could be
    nested inside other columns.

    Attributes:
        column (str):
            Required. Name of the column.
        type_ (str):
            Required. Type of the column.
        description (str):
            Optional. Description of the column. Default
            value is an empty string.
        mode (str):
            Optional. A column's mode indicates whether the values in
            this column are required, nullable, etc. Only ``NULLABLE``,
            ``REQUIRED`` and ``REPEATED`` are supported. Default mode is
            ``NULLABLE``.
        subcolumns (MutableSequence[google.cloud.datacatalog_v1beta1.types.ColumnSchema]):
            Optional. Schema of sub-columns. A column can
            have zero or more sub-columns.
    """

    column: str = proto.Field(
        proto.STRING,
        number=6,
    )
    type_: str = proto.Field(
        proto.STRING,
        number=1,
    )
    description: str = proto.Field(
        proto.STRING,
        number=2,
    )
    mode: str = proto.Field(
        proto.STRING,
        number=3,
    )
    subcolumns: MutableSequence["ColumnSchema"] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message="ColumnSchema",
    )


__all__ = tuple(sorted(__protobuf__.manifest))
